@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
 # Pong Example
-# Written in 2013, 2014 by Julian Marchant <onpon4@riseup.net>
+# Written in 2013, 2014, 2015 by Julian Marchant <onpon4@riseup.net>
 #
 # To the extent possible under law, the author(s) have dedicated all
 # copyright and related and neighboring rights to this software to the
@@ -38,12 +38,6 @@ game_in_progress = True
 
 class Game(sge.Game):
 
-    def event_game_start(self):
-        self.mouse.visible = False
-        self.fps_time = 0
-        self.fps_frames = 0
-        self.fps_text = ""
-
     def event_step(self, time_passed, delta_mult):
         self.project_sprite(hud_sprite, 0, self.width / 2, 0)
 
@@ -72,7 +66,7 @@ class Game(sge.Game):
                 self.pause()
             else:
                 game_in_progress = True
-                self.current_room.start()
+                create_room().start()
 
     def event_close(self):
         self.end()
@@ -214,23 +208,32 @@ class Ball(sge.Object):
             p2text = "WIN" if player2.score > player1.score else "LOSE"
             hud_sprite.draw_text(hud_font, p1text, x - TEXT_OFFSET,
                                  TEXT_OFFSET, color=sge.Color("white"),
-                                 halign=sge.ALIGN_RIGHT, valign=sge.ALIGN_TOP)
+                                 halign="right", valign="top")
             hud_sprite.draw_text(hud_font, p2text, x + TEXT_OFFSET,
                                  TEXT_OFFSET, color=sge.Color("white"),
-                                 halign=sge.ALIGN_LEFT, valign=sge.ALIGN_TOP)
+                                 halign="left", valign="top")
             game_in_progress = False
 
 
+def create_room():
+    global player1
+    global player2
+    player1 = Player(1)
+    player2 = Player(2)
+    ball = Ball()
+    return sge.Room([player1, player2, ball], background=background)
+
+
 def refresh_hud():
     # This fixes the HUD sprite so that it displays the correct score.
     hud_sprite.draw_clear()
     x = hud_sprite.width / 2
     hud_sprite.draw_text(hud_font, str(player1.score), x - TEXT_OFFSET,
                          TEXT_OFFSET, color=sge.Color("white"),
-                         halign=sge.ALIGN_RIGHT, valign=sge.ALIGN_TOP)
+                         halign="right", valign="top")
     hud_sprite.draw_text(hud_font, str(player2.score), x + TEXT_OFFSET,
                          TEXT_OFFSET, color=sge.Color("white"),
-                         halign=sge.ALIGN_LEFT, valign=sge.ALIGN_TOP)
+                         halign="left", valign="top")
 
 
 # Create Game object
@@ -247,7 +250,7 @@ hud_sprite = sge.Sprite(width=320, height=120, origin_x=160, origin_y=0)
 
 # Load backgrounds
 layers = [sge.BackgroundLayer(paddle_sprite, sge.game.width / 2, 0, -10000,
-                              xrepeat=False)]
+                              repeat_up=True, repeat_down=True)]
 background = sge.Background(layers, sge.Color("black"))
 
 # Load fonts
@@ -258,13 +261,13 @@ bounce_sound = sge.Sound(os.path.join(DATA, 'bounce.wav'))
 bounce_wall_sound = sge.Sound(os.path.join(DATA, 'bounce_wall.wav'))
 score_sound = sge.Sound(os.path.join(DATA, 'score.wav'))
 
-# Create objects
-player1 = Player(1)
-player2 = Player(2)
-ball = Ball()
-
 # Create rooms
-sge.game.start_room = sge.Room([player1, player2, ball], background=background)
+sge.game.start_room = create_room()
+
+sge.game.mouse.visible = False
+sge.game.fps_time = 0
+sge.game.fps_frames = 0
+sge.game.fps_text = ""
 
 
 if __name__ == '__main__':
