@@ -1,5 +1,5 @@
 # Copyright (c) 2014 Edwin O Marshall <edwin@directemployers.org>
-# Copyright (c) 2014 Julian Marchant <onpon4@riseup.net>
+# Copyright (c) 2014, 2015 Julian Marchant <onpon4@riseup.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -176,6 +176,9 @@ class Color(object):
     def __int__(self):
         return self.red * 256 ** 2 | self.green * 256 | self.blue
 
+    def __repr__(self):
+        return 'sge.Color("{}")'.format(str(self))
+
     def __str__(self):
         return COLOR_NAMES.get(self.hex_string, self.hex_string)
 
