@@ -1,5 +1,5 @@
 # The SGE Specification
-# Written in 2012, 2013, 2014 by Julian Marchant <onpon4@riseup.net> 
+# Written in 2012, 2013, 2014, 2015 by Julian Marchant <onpon4@riseup.net> 
 # 
 # To the extent possible under law, the author(s) have dedicated all
 # copyright and related and neighboring rights to this software to the
@@ -171,9 +171,8 @@ class Game(object):
 
     def start(self):
         """
-        Start the game at the first room.  Can be called in the middle
-        of a game to start the game over.  If you do this, everything
-        will be reset to its original state.
+        Start the game.  Should only be called once; the effect of any
+        further calls is undefined.
         """
         # TODO
 
@@ -385,8 +384,8 @@ class Game(object):
         # TODO
 
     def project_text(self, font, text, x, y, width=None, height=None,
-                    color=sge.Color("black"), halign=sge.ALIGN_LEFT,
-                    valign=sge.ALIGN_TOP, anti_alias=True):
+                    color=sge.Color("black"), halign="left",
+                    valign="top", anti_alias=True):
         """
         Project text onto the game window.
 
@@ -402,21 +401,6 @@ class Game(object):
         """
         # TODO
 
-    def event_game_start(self):
-        """
-        Called when the game starts.  This is only called once (it is
-        not called again when the game restarts), and it is always the
-        very first event method called.
-        """
-        pass
-
-    def event_game_end(self):
-        """
-        Called when the game ends.  This is only called once, and it is
-        always the very last event method called.
-        """
-        pass
-
     def event_step(self, time_passed, delta_mult):
         """
         Called once each frame.
@@ -435,7 +419,7 @@ class Game(object):
         """
         Called when the value of an alarm reaches 0.
 
-        See the documentation for :meth:`sge.Game.alarms` for more
+        See the documentation for :attr:`sge.Game.alarms` for more
         information.
         """
         pass
@@ -551,44 +535,50 @@ class Game(object):
     def event_mouse_collision(self, other):
         """
         Proxy for :meth:`sge.game.mouse.event_collision`.  See the
-        documentation for :meth:`sge.Object.event_collision` for
-        more information.
+        documentation for :meth:`sge.Object.event_collision` for more
+        information.
         """
         pass
 
     def event_mouse_collision_left(self, other):
         """
         Proxy for :meth:`sge.game.mouse.event_collision_left`.  See the
-        documentation for :meth:`sge.Object.event_collision_left`
-        for more information.
+        documentation for :meth:`sge.Object.event_collision_left` for
+        more information.
         """
         self.event_mouse_collision(other)
 
     def event_mouse_collision_right(self, other):
         """
         Proxy for :meth:`sge.game.mouse.event_collision_right`.  See the
-        documentation for :meth:`sge.Object.event_collision_right`
-        for more information.
+        documentation for :meth:`sge.Object.event_collision_right` for
+        more information.
         """
         self.event_mouse_collision(other)
 
     def event_mouse_collision_top(self, other):
         """
         Proxy for :meth:`sge.game.mouse.event_collision_top`.  See the
-        documentation for :meth:`sge.Object.event_collision_top`
-        for more information.
+        documentation for :meth:`sge.Object.event_collision_top` for
+        more information.
         """
         self.event_mouse_collision(other)
 
     def event_mouse_collision_bottom(self, other):
         """
         Proxy for :meth:`sge.game.mouse.event_collision_bottom`.  See
-        the documentation for
-        :meth:`sge.Object.event_collision_bottom` for more
-        information.
+        the documentation for :meth:`sge.Object.event_collision_bottom`
+        for more information.
         """
         self.event_mouse_collision(other)
 
+    def event_paused_step(self, time_passed, delta_mult):
+        """
+        See the documentation for :meth:`sge.Game.event_step` for more
+        information.
+        """
+        pass
+
     def event_paused_key_press(self, key, char):
         """
         See the documentation for :class:`sge.input.KeyPress` for more
