@@ -1,5 +1,5 @@
 # The SGE Specification
-# Written in 2012, 2013, 2014 by Julian Marchant <onpon4@riseup.net> 
+# Written in 2012, 2013, 2014, 2015 by Julian Marchant <onpon4@riseup.net> 
 # 
 # To the extent possible under law, the author(s) have dedicated all
 # copyright and related and neighboring rights to this software to the
@@ -402,9 +402,7 @@ class Object(object):
 
     def event_end_step(self, time_passed, delta_mult):
         """
-        Called each frame after automatic updates to objects (such as
-        the effects of the speed variables), but before collision
-        events.
+        Called each frame after collision events.
 
         See the documentation for :meth:`sge.Game.event_step` for more
         information.
@@ -413,7 +411,7 @@ class Object(object):
 
     def event_alarm(self, alarm_id):
         """
-        See the documentation for :meth:`sge.Object.alarms` for more
+        See the documentation for :attr:`sge.Object.alarms` for more
         information.
         """
         pass
@@ -697,6 +695,13 @@ class Object(object):
         """
         pass
 
+    def event_paused_step(self, time_passed, delta_mult):
+        """
+        See the documentation for :meth:`sge.Game.event_step` for more
+        information.
+        """
+        pass
+
     def event_paused_key_press(self, key, char):
         """
         See the documentation for :class:`sge.input.KeyPress` for more
